OC.L10N.register(
    "twofactor_backupcodes",
    {
    "You created two-factor backup codes for your account" : "Usted ha creado códigos de respaldo de dos factores para su cuenta",
    "Second-factor backup codes" : "Códigos de respaldo del segundo factor",
    "Generate backup codes" : "Generar códigos de respaldo",
    "Backup code" : "Código de respaldo",
    "Use backup code" : "Use el código de respaldo",
    "Two factor backup codes" : "Códigos de respaldo de dos factores",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Estos son sus códigos de respaldo. Favor de resguardarlos y/o imprimirlos ya que no podrá leerlos otra vez después. ",
    "Save backup codes" : "Guardar códigos de respaldo",
    "Print backup codes" : "Imprimir códigos de respaldo",
    "Regenerate backup codes" : "Regenerar códigos de respaldo",
    "If you regenerate backup codes, you automatically invalidate old codes." : "Si usted regenera los códigos de respaldo, automáticamente invalidará los anteriores. ",
    "An error occurred while generating your backup codes" : "Se presentó un error al generar sus códigos de respaldo. ",
    "Submit" : "Enviar"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
